<img src="https://raw.githubusercontent.com/pliablepixels/pyzm/master/images/pyzm.png" width="200"/>

What
=====
Pythonic ZoneMinder wrapper
- API
- Event Server
- Logger
- Memory

Documentation & Examples
=========================
Latest documentation is available <a href='https://pyzm.readthedocs.io/en/latest/'>here</a>. The documentation includes a full example.

Features
=========
- API auth using tokens or legacy (manages refresh logins automatically)
- Monitors
- Events with filters
- States
- Configs
- EventNotification callbacks
- Mapped Memory access

Limitations
============
* Only for Python3



